@@ -17,7 +17,7 @@ Version 1.01
 
 =cut
 
-$VERSION = '1.03_01';
+$VERSION = '1.01';
 
 =head1 SYNOPSIS
 
@@ -127,16 +127,8 @@ sub guess_base {
     return guess_system_path();
 }
 
-## we want to use PWD if it exists (it's not guaranteed on all platforms)
-## so that we have a sense of the shell current working dir, with unresolved
-## symlinks
-sub guess_pwd {
-    return $ENV{PWD} || Cwd::cwd();
-}
-
 sub guess_shell_path {
-    my $pwd = guess_pwd();
-    my ($volume, $path, $file) = File::Spec->splitpath($pwd);
+    my ($volume, $path, $file) = File::Spec->splitpath( $ENV{PWD} );
     my @path = File::Spec->splitdir($path);
     pop @path unless $path[-1];
     @base = (@path, $file);
